# $Id: pybbib.py,v 1.15 2009/08/19 08:05:03 jhh Exp $
#
# Author: Jaap-Henk Hoepman (jhh@xs4all.nl)
#
# Class BibEntry to handle bibtex entries
#
# - A bibtex entry is stored as python dictionary, where the key in the
#   dictionary (a string with double quotes) corresponds to the bibtex
#   fieldname (without those quotes), and the value stores
#   the value (in both cases with "" or {}). The dictionary holds
#   an extra key "mytype" for the type (@...) of the bibtex entry and an extra
#   key "mykey" for the key corresponding to this bibtex entry
#   (but stored without quotes).
#
# adapted to python3

class BibEntry():

    # the entry, stored as a dictionary
    entry = [] 

    # Create a bibtex entry, of type 'tp' and with key 'key', with the dictionary 'values' as initial
    # value
    def __init__(self,tp,key,values):
        self.entry = values
        self.entry["mytype"] = tp
        self.entry["mykey"] = key

    # does this entry have a cross reference entry?
    def hasxref(self):
        return "crossref" in self.entry

    # return the cite key of the cross reference in this entry
    def getxref(self):
        xref = ""
        if "crossref" in self.entry:
            xref = self.entry["crossref"]
            xref = xref.strip()
            xref = xref.strip("{}")
            xref = xref.strip("\"\"")
        return xref

    # Write this bibtex entry to the open textfile f.
    def write(self,f):
        f.write("@" + self.entry['mytype'] + "{" + self.entry['mykey'] + ",\n")
        for key,value in self.entry.items():
            # ignore our extra bookkeeping entries
            if key not in ["mytype","mykey"]:
                f.write('\t' + key + ' = ' + value + ',\n')
        f.write("}\n\n")

